Publications
============
Links to publications and associate source code.

Nempy Technical Brief
---------------------
Soon to be published technical brief will be available here.

Source code for Figure 1
************************

.. literalinclude:: ../../publications/all_features_example.py
    :linenos:
    :language: python

Source code for Figure 2
************************

.. literalinclude:: ../../publications/energy_only_market.py
    :linenos:
    :language: python
